==> pinta_1.6.orig.tar.gz: pinta-1.6/Pinta/Actions/View/ToolBarToggledAction.cs <==
﻿// 
// ToolBarToggledAction.cs
//  
// Author:
//       Jonathan Pobst <monkey@jpobst.com>
// 
// Copyright (c) 2010 Jonathan Pobst
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using Pinta.Core;
using Gtk;

namespace Pinta.Actions
{
	class ToolBarToggledAction : IActionHandler
	{
		#region IActionHandler Members
		public void Initialize ()
		{
			PintaCore.Actions.View.ToolBar.Toggled += Activated;
		}

		public void Uninitialize ()
		{
			PintaCore.Actions.View.ToolBar.Toggled -= Activated;
		}
		#endregion

		private void Activated (object sender, EventArgs e)
		{
			PintaCore.Chrome.MainToolBar.Visible = ((ToggleAction)sender).Active;
		}
	}
}

==> pinta-3.0.1.tar.gz: pinta-3.0.1/Pinta/Actions/View/ToolBarToggledAction.cs <==
// 
// ToolBarToggledAction.cs
//  
// Author:
//       Jonathan Pobst <monkey@jpobst.com>
// 
// Copyright (c) 2010 Jonathan Pobst
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using Pinta.Core;

namespace Pinta.Actions;

internal sealed class ToolBarToggledAction : IActionHandler
{
	private readonly ViewActions view;
	private readonly ChromeManager chrome;
	internal ToolBarToggledAction (
		ViewActions view,
		ChromeManager chrome)
	{
		this.view = view;
		this.chrome = chrome;
	}

	void IActionHandler.Initialize ()
	{
		view.ToolBar.Toggled += Activated;
	}

	void IActionHandler.Uninitialize ()
	{
		view.ToolBar.Toggled -= Activated;
	}

	private void Activated (bool value, bool interactive)
	{
		if (chrome.MainToolBar is not null)
			chrome.MainToolBar.Visible = value;
	}
}
